/**********************************************************
　　製作者　　アドウィン
　　解　説　　ロータリエンコーダの回転方向検出 – プログラム例
**********************************************************/
#include <Arduino.h>      // Arduino.h の読み込み
#include "char8x8.h"      // char8x8.h の読み込み
#include "dotmatrixled.h" // dotmatrixled.h の読み込み

// ロータリエンコーダ用のピン
int encAPin = 26;
int encBPin = 27;
// クリック数
int click = 0;

/*
 * setup 関数
 */
void setup() {
  /* ここにプログラムの最初に1回だけ実行したい処理を上から順に記述していきます */

  // シリアル通信を115200bpsで開始
  Serial.begin(115200);

  Serial.println("初期設定の開始");

  // ドットマトリクスLED初期設定
  initLed();

  // ロータリエンコーダ用ピンの初期設定
  pinMode(encAPin, INPUT_PULLUP);
  pinMode(encBPin, INPUT_PULLUP);

  Serial.println("初期設定の完了");
}

/*
 * loop 関数
 */
void loop() {
  /* ここにプログラム中で繰り返し実行したい処理を上から順に記述していきます */

  // シリアルモニタに出力
  Serial.printf(" φ A: %d, φ B %d, click: %d\n",
  digitalRead(encAPin), digitalRead(encBPin), click);

  // ドットマトリクスLEDのclick行目を点灯
  setLed(0xFF, ledCathodePattern[click]);

  // 今回のφAの値
  int valA = digitalRead(encAPin);
  // 今回のφBの値
  int valB = digitalRead(encBPin);
  // ロータリエンコーダの状態の取得
  int state;
  if (valB == HIGH) {
    if (valA == HIGH)
      state = 0;
    else
      state = 1;
  } else {
    if (valA == LOW)
      state = 2;
    else
      state = 3;
  }
  // 前回のロータリエンコーダの状態
  static int prevState = state;

  // 前回が状態2で今回が状態3の時、クリック数をカウントアップ（右回転）
  if (2 == prevState && 3 == state) {
    // クリック数を1増やす
    click++;
    // クリック数が7を超えた時、ゼロに戻す
    if (click > 7)
      click = 0;
  }

  // 前回が状態3で今回が状態2の時、クリック数をカウントダウン（左回転）
  if (3 == prevState && 2 == state) {
    // クリック数を1減らす
    click--;
    // クリック数が0未満の時、7に戻す
    if (click < 0)
      click = 7;
  }

  // 前回の状態を更新
  prevState = state;

  delay(1); // 時間待ち
}