/**********************************************************
　　製作者　　アドウィン
　　解　説　　SWとの組み合わせ – プログラム例
**********************************************************/
#include <Arduino.h> // Arduino.h の読み込み
#include "switch.h"  // switch.h の読み込み

// スピーカ用ピンの設定
int speaker = 25;
// スピーカ用PWMチャンネルの設定
int speakerPwm = 0;

// サーボモータ用ピンの設定
int servo = 4;
// サーボモータ用PWMチャンネルの設定
int servoPwm = 2;
// サーボモータの角度
int angle = 0;

/*
 * setup 関数
 */
void setup() {
  /* ここにプログラムの最初に1回だけ実行したい処理を上から順に記述していきます */

  // シリアル通信を115200bpsで開始
  Serial.begin(115200);

  Serial.println("初期設定の開始");

  // スイッチの初期設定
  initSwitch();

  // スピーカのPWMの設定
  // PWMピンを出力ピンに設定
  pinMode(speaker, OUTPUT);
  // PWMチャンネルを440Hz、16ビット（0〜65536）に設定
  ledcSetup(speakerPwm, 440, 16);
  // PWMピンとPWMチャンネルを結びつける
  ledcAttachPin(speaker, speakerPwm);
  // PWMのデューティ比を50%に設定
  ledcWrite(speakerPwm, 0.5 * 65536);

  // サーボモータのPWMの設定
  // PWMピンを出力ピンに設定
  pinMode(servo, OUTPUT);
  // PWMチャンネルを50Hz、16ビット（0〜65536）に設定
  ledcSetup(servoPwm, 50, 16);
  // PWMピンとPWMチャンネルを結びつける
  ledcAttachPin(servo, servoPwm);
  // PWMのデューティを1.5msに設定
  ledcWrite(servoPwm, (1.5 / 20) * 65536);

  Serial.println("初期設定の完了");
}

/*
 * loop 関数
 */
void loop() {
  /* ここにプログラム中で繰り返し実行したい処理を上から順に記述していきます */

  // SW1だけが押されている時、角度を1度増やす
  if (SW1_ON && SW2_OFF) {
    // 角度を1度増やす
    angle++;
    // 上限60度
    if (angle > 60)
      angle = 60;
  }
  // SW2だけが押されている時、角度を1度減らす
  else if (SW1_OFF && SW2_ON) {
    // 角度を1度減らす
    angle--;
    // 下限-60度
    if (angle < -60)
      angle = -60;
  }
  // SW1とSW2が同時に押されている時、角度を0度に
  else if (SW1_ON && SW2_ON) {
    // 角度を0に
    angle = 0;
  }

  // サーボモータ用PWMのデューティ比の設定
  ledcWrite(servoPwm, ((1.5 + 0.01 * angle) / 20) * 65536);

  // 時間待ち
  delay(10);
}